#include <File.au3>
#include <Array.au3>
#include <SQLite.au3>

AutoItSetOption("MustDeclareVars", 1)

Global $PATH_SQLITE3_DLL = @ScriptDir & "\sqlite3.dll"
Global $PATH_BDD = @ScriptDir & "\bdd"
Global $PATH_LOG = @ScriptDir & "\fil.log"

Call("main", $CmdLine[0])

Func main($argc)
	
	Global $path = argTest($argc)
	Local $tmp_error = @error
	Global $h_bdd
	Global $table_name
	Local $begin = TimerInit()
	Local $p_dir, $p_name, $p_ext, $p_drive
	If $tmp_error Then Exit ($tmp_error)

	_PathSplit($path, $p_drive, $p_dir, $p_name, $p_ext)
	$table_name = $p_name
	
	If FileExists($PATH_SQLITE3_DLL) Then
		_SQLite_Startup($PATH_SQLITE3_DLL)
	Else
		_SQLite_Startup()
	EndIf
	
	If @error > 0 Then Exit (3)
	$h_bdd = _SQLite_Open($PATH_BDD)
	If ($h_bdd == 0) Then Exit (4)

	If (create_bdd() == -1) Then Exit (5)
	
	write_file($path)
	
	_FileWriteLog($PATH_LOG, "Temps d'execution: " & Round(TimerDiff($begin) / 1000, 1) & " s | nom de la table -> "& $table_name, 0)
	_SQLite_Shutdown()
	Exit (0)
	
EndFunc   ;==>main

Func argTest(ByRef $argc)
	Local $tmp_path
	
	If $argc < 1 Then
		SetError(1)
	Else
		If Not IsString($CmdLine[1]) Then
			SetError(2)
		Else
			$tmp_path = StringReplace($CmdLine[1], "/", "\")
			If StringRight($tmp_path, 1) == "\" Then $tmp_path = StringTrimRight($tmp_path, 1)
		EndIf
	EndIf
	
	Return $tmp_path
EndFunc   ;==>argTest

Func create_bdd()
	Dim $table_name, $h_bdd
	Local $query, $row
	
	_SQLite_Query($h_bdd, 'CREATE TABLE ' & $table_name & ' ( id INTEGER PRIMARY KEY, nom VARCHAR(100) , extension VARCHAR(20) , chemin VARCHAR(300) );', $query)
	While (_SQLite_FetchData($query, $row) == $SQLITE_OK)
	WEnd

	If (_SQLite_ErrCode() <> 0) Then Return -1
	Return 0
EndFunc   ;==>create_bdd

Func write_file($path_cur)
	Local $fileListRoot, $folderListRoot, $h_bdd, $query, $row
	Dim $table_name
	$fileListRoot = _FileListToArray($path_cur, "*.*", 1)
	If (@error = 0) Then
		For $i = 1 To $fileListRoot[0]
			_SQLite_Query($h_bdd, 'INSERT INTO ' & $table_name & ' (nom,extension,chemin) VALUES ("' & _
					$fileListRoot[$i] & '","' & _
					get_extension($fileListRoot[$i]) & '","' & $path_cur & '");', $query)
			While (_SQLite_FetchData($query, $row) == $SQLITE_OK)
			WEnd
		Next
	EndIf
	
	$folderListRoot = _FileListToArray($path_cur, "*.*", 2)
	If @error = 4 Then
		Return
	Else
		For $i = 1 To $folderListRoot[0]
			write_file($path_cur & "\" & $folderListRoot[$i])
		Next
	EndIf
EndFunc   ;==>write_file

Func get_extension($fileName)
	Local $array = StringSplit($fileName, ".")
	If IsArray($array) And UBound($array) > 1 Then Return $array[$array[0]]
	Return ""
EndFunc   ;==>get_extension

Func OnAutoItExit()
	
	Dim $h_bdd, $table_name

	If $h_bdd <> 0 Or _SQLite_ErrCode() <> 0 Then _SQLite_Shutdown()
	
	Switch (@exitCode)
		Case 1 To 2
			_FileWriteLog($PATH_LOG, "Erreur->Mauvaise utilisation: " & @ScriptName & " C:\Program Files pour indexer le dossier Program Files", 0)
		Case 3
			_FileWriteLog($PATH_LOG, "Erreur->Impossible de charger la Dll->" & $PATH_SQLITE3_DLL, 0)
		Case 4
			_FileWriteLog($PATH_LOG, "Erreur->Impossible d'ouvrir la Bdd->" & @CRLF & $PATH_BDD, 0)
		Case 5
			_FileWriteLog($PATH_LOG, "Erreur->Impossible de cre la table " & $table_name & " dans la Bdd->" & $PATH_BDD, 0)
	EndSwitch
EndFunc   ;==>OnAutoItExit